.. currentmodule:: sardana.pool

.. _sardana-countertimer-overview:

=======================
Counter/timer overview
=======================

.. todo:: document counter/timer overview

.. seealso:: 
    
    :ref:`sardana-countertimer-api`
        the counter/timer :term:`API` 
    
    :class:`~sardana.tango.pool.CTExpChannel.CTExpChannel`
        the counter/timer tango device :term:`API`
